==> jc-1.4.0.tar.gz: soot/UnknownMethodSource.h <==
// public class soot.UnknownMethodSource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c2f8a579c8aaa450 soot_UnknownMethodSource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_UnknownMethodSource_H_
#define _JC_soot_UnknownMethodSource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_UnknownMethodSource$sub_refs	_jc_soot_UnknownMethodSource$sub_refs;
typedef struct _jc_soot_UnknownMethodSource$sub_nonrefs	_jc_soot_UnknownMethodSource$sub_nonrefs;
typedef struct _jc_soot_UnknownMethodSource$refs	_jc_soot_UnknownMethodSource$refs;
typedef struct _jc_soot_UnknownMethodSource$nonrefs	_jc_soot_UnknownMethodSource$nonrefs;
typedef struct _jc_soot_UnknownMethodSource$object	_jc_soot_UnknownMethodSource$object;

typedef const struct _jc_soot_UnknownMethodSource$vmethods	_jc_soot_UnknownMethodSource$vmethods;
typedef const struct _jc_soot_UnknownMethodSource$vtable	_jc_soot_UnknownMethodSource$vtable;
typedef const struct _jc_soot_UnknownMethodSource$vtype	_jc_soot_UnknownMethodSource$vtype;

// Constructors
extern void _jc_soot_UnknownMethodSource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_UnknownMethodSource$object *);

// Virtual methods
extern struct _jc_soot_Body$object *_jc_soot_UnknownMethodSource$method$getBody$01a871f1d690f082(_jc_env *, struct _jc_soot_UnknownMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_UnknownMethodSource$method_info$getBody$01a871f1d690f082;

// Virtual methods structure
struct _jc_soot_UnknownMethodSource$vmethods {
	struct _jc_soot_Body$object	*(*getBody$01a871f1d690f082)(_jc_env *, struct _jc_soot_UnknownMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_soot_UnknownMethodSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_UnknownMethodSource$vmethods	soot_UnknownMethodSource;
};

// Vtype
struct _jc_soot_UnknownMethodSource$vtype {
	_jc_type			type;
	_jc_soot_UnknownMethodSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_UnknownMethodSource$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_UnknownMethodSource$refs {
    _jc_soot_UnknownMethodSource$sub_refs	soot_UnknownMethodSource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_UnknownMethodSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_UnknownMethodSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_UnknownMethodSource$sub_nonrefs	soot_UnknownMethodSource;
};

// Object instance structure
struct _jc_soot_UnknownMethodSource$object {
	_jc_soot_UnknownMethodSource$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_UnknownMethodSource$vtype	*vtype;
	_jc_soot_UnknownMethodSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_UnknownMethodSource$vtype _jc_soot_UnknownMethodSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_UnknownMethodSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_UnknownMethodSource$class_object;

#endif	/* _JC_soot_UnknownMethodSource_H_ */

==> jc-1.4.6.tar.gz: soot/UnknownMethodSource.h <==
// public class soot.UnknownMethodSource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c2f8a579c8aaa450 soot_UnknownMethodSource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_UnknownMethodSource_H_
#define _JC_soot_UnknownMethodSource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_UnknownMethodSource$sub_refs	_jc_soot_UnknownMethodSource$sub_refs;
typedef struct _jc_soot_UnknownMethodSource$sub_nonrefs	_jc_soot_UnknownMethodSource$sub_nonrefs;
typedef struct _jc_soot_UnknownMethodSource$refs	_jc_soot_UnknownMethodSource$refs;
typedef struct _jc_soot_UnknownMethodSource$nonrefs	_jc_soot_UnknownMethodSource$nonrefs;
typedef struct _jc_soot_UnknownMethodSource$object	_jc_soot_UnknownMethodSource$object;

typedef const struct _jc_soot_UnknownMethodSource$vmethods	_jc_soot_UnknownMethodSource$vmethods;
typedef const struct _jc_soot_UnknownMethodSource$vtable	_jc_soot_UnknownMethodSource$vtable;
typedef const struct _jc_soot_UnknownMethodSource$vtype	_jc_soot_UnknownMethodSource$vtype;

// Constructors
extern void _jc_soot_UnknownMethodSource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_UnknownMethodSource$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_Body$object *_jc_soot_UnknownMethodSource$method$getBody$01a871f1d690f082(_jc_env *, struct _jc_soot_UnknownMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_UnknownMethodSource$method_info$getBody$01a871f1d690f082;

// Virtual methods structure
struct _jc_soot_UnknownMethodSource$vmethods {
	struct _jc_soot_Body$object	*(*getBody$01a871f1d690f082)(_jc_env *, struct _jc_soot_UnknownMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_UnknownMethodSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_UnknownMethodSource$vmethods	soot_UnknownMethodSource;
};

// Vtype
struct _jc_soot_UnknownMethodSource$vtype {
	_jc_type			type;
	_jc_soot_UnknownMethodSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_UnknownMethodSource$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_UnknownMethodSource$refs {
    _jc_soot_UnknownMethodSource$sub_refs	soot_UnknownMethodSource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_UnknownMethodSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_UnknownMethodSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_UnknownMethodSource$sub_nonrefs	soot_UnknownMethodSource;
};

// Object instance structure
struct _jc_soot_UnknownMethodSource$object {
	_jc_soot_UnknownMethodSource$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_UnknownMethodSource$vtype	*vtype;
	_jc_soot_UnknownMethodSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_UnknownMethodSource$vtype _jc_soot_UnknownMethodSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_UnknownMethodSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_UnknownMethodSource$class_object;

#endif	/* _JC_soot_UnknownMethodSource_H_ */
